<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# Unreleased Feature

This page is in `_drafts/` — a private directory that Zensical never serves.

Any link from a public page to this file will trigger **UNREACHABLE_LINK**
in Zenzic because files and directories starting with `_` are treated as private.
